@@ -1,6 +1,8 @@
 from django import forms
 from django.forms import ModelForm
-from collection.models import Product
+
+from suave.models import Page
+from collection.models import Product, Category
 
 
 class LoginForm(forms.Form):
@@ -18,3 +20,15 @@ class ProductTableRow(ModelForm):
     class Meta:
         model = Product
         fields = ('featured', 'sold', 'category',)
+
+
+class PageForm(ModelForm):
+    class Meta:
+        model = Page
+        exclude = ('identifier', 'url', 'template_override',)
+
+
+class CategoryForm(ModelForm):
+    class Meta:
+        model = Category
+        #exclude = ('identifier', 'url', 'template_override',)
